@@ -1140,6 +1140,18 @@ bool CSoundFile::ReadS3ISample(SAMPLEINDEX nSample, FileReader &file)
 		return false;
 	}
 
+	if(sampleHeader.sampleType >= S3MSampleHeader::typeAdMel)
+	{
+		if(SupportsOPL())
+		{
+			InitOPL();
+		} else
+		{
+			AddToLog(LogInformation, U_("OPL instruments are not supported by this format."));
+			return true;
+		}
+	}
+
 	DestroySampleThreadsafe(nSample);
 
 	ModSample &sample = Samples[nSample];
@@ -1148,10 +1160,6 @@ bool CSoundFile::ReadS3ISample(SAMPLEINDEX nSample, FileReader &file)
 
 	if(sampleHeader.sampleType < S3MSampleHeader::typeAdMel)
 		sampleHeader.GetSampleFormat(false).ReadSample(sample, file);
-	else if(SupportsOPL())
-		InitOPL();
-	else
-		AddToLog(LogInformation, U_("OPL instruments are not supported by this format."));
 
 	sample.Convert(MOD_TYPE_S3M, GetType());
 	sample.PrecomputeLoops(*this, false);
@@ -1163,8 +1171,7 @@ bool CSoundFile::ReadS3ISample(SAMPLEINDEX nSample, FileReader &file)
 bool CSoundFile::SaveS3ISample(SAMPLEINDEX smp, std::ostream &f) const
 {
 	const ModSample &sample = Samples[smp];
-	S3MSampleHeader sampleHeader;
-	MemsetZero(sampleHeader);
+	S3MSampleHeader sampleHeader{};
 	SmpLength length = sampleHeader.ConvertToS3M(sample);
 	mpt::String::WriteBuf(mpt::String::nullTerminated, sampleHeader.name) = m_szNames[smp];
 	mpt::String::WriteBuf(mpt::String::maybeNullTerminated, sampleHeader.reserved2) = mpt::ToCharset(mpt::Charset::UTF8, Version::Current().GetOpenMPTVersionString());
@@ -1186,9 +1193,10 @@ bool CSoundFile::SaveS3ISample(SAMPLEINDEX smp, std::ostream &f) const
 bool CSoundFile::ReadSBISample(SAMPLEINDEX sample, FileReader &file)
 {
 	file.Rewind();
-	if(!file.ReadMagic("SBI\x1A")
-		|| !file.CanRead(32 + sizeof(OPLPatch))
-		|| file.CanRead(64))	// Arbitrary threshold to reject files that are unlikely to be SBI files
+	const auto magic = file.ReadArray<char, 4>();
+	if((memcmp(magic.data(), "SBI\x1A", 4) && memcmp(magic.data(), "SBI\x1D", 4))  // 1D =  broken JuceOPLVSTi files
+	   || !file.CanRead(32 + sizeof(OPLPatch))
+	   || file.CanRead(64))  // Arbitrary threshold to reject files that are unlikely to be SBI files
 		return false;
 
 	if(!SupportsOPL())
@@ -1751,7 +1759,6 @@ bool CSoundFile::ReadCAFSample(SAMPLEINDEX nSample, FileReader &file, bool mayNo
 }
 
 
-
 /////////////////////////////////////////////////////////////////////////////////////////
 // AIFF File I/O
 
