@@ -1074,6 +1074,7 @@ PlayBehaviourSet CSoundFile::GetSupportedPlaybackBehaviour(MODTYPE type)
 		playBehaviour.set(kITDoNotOverrideChannelPan);
 		playBehaviour.set(kITDCTBehaviour);
 		playBehaviour.set(kITPitchPanSeparation);
+		playBehaviour.set(kITResetFilterOnPortaSmpChange);
 		if(type == MOD_TYPE_MPT)
 		{
 			playBehaviour.set(kOPLFlexibleNoteOff);
@@ -2045,6 +2046,7 @@ void TempoSwing::Normalize()
 		sum += i;
 	}
 	sum /= size();
+	MPT_ASSERT(sum > 0); // clang-analyzer false-positive 
 	int64 remain = Unity * size();
 	for(auto &i : *this)
 	{
